==> apache-geode-1.14.4-src.tgz: apache-geode-1.14.4-src/geode-core/src/test/java/org/apache/geode/internal/cache/DestroyMessageTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.Matchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Test;

import org.apache.geode.internal.cache.DestroyOperation.DestroyMessage;

public class DestroyMessageTest {

  @Test
  public void shouldBeMockable() throws Exception {
    DestroyMessage mockDestroyOperation = mock(DestroyMessage.class);
    DistributedRegion mockDistributedRegion = mock(DistributedRegion.class);
    InternalCacheEvent mockInternalCacheEvent = mock(InternalCacheEvent.class);

    when(mockDestroyOperation.createEvent(eq(mockDistributedRegion)))
        .thenReturn(mockInternalCacheEvent);

    assertThat(mockDestroyOperation.createEvent(mockDistributedRegion))
        .isEqualTo(mockInternalCacheEvent);
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-core/src/test/java/org/apache/geode/internal/cache/DestroyMessageTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.internal.cache;

import static org.assertj.core.api.Assertions.assertThat;
import static org.mockito.ArgumentMatchers.eq;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import org.junit.Test;

import org.apache.geode.internal.cache.DestroyOperation.DestroyMessage;

public class DestroyMessageTest {

  @Test
  public void shouldBeMockable() throws Exception {
    DestroyMessage mockDestroyOperation = mock(DestroyMessage.class);
    DistributedRegion mockDistributedRegion = mock(DistributedRegion.class);
    InternalCacheEvent mockInternalCacheEvent = mock(InternalCacheEvent.class);

    when(mockDestroyOperation.createEvent(eq(mockDistributedRegion)))
        .thenReturn(mockInternalCacheEvent);

    assertThat(mockDestroyOperation.createEvent(mockDistributedRegion))
        .isEqualTo(mockInternalCacheEvent);
  }
}
